{% extends "kegadmin/base.html" %}
{% load kegweblib %}
{% load crispy_forms_tags %}

{% block title %}Kegbot Admin: General Settings | {{ block.super }}{% endblock %}
{% block pagetitle %}Kegbot Admin: General Settings{% endblock %}

{% block kegadmin-main %}
  {% crispy settings_form %}
{% endblock %}
